@@ -1,11 +1,11 @@
 #!/usr/bin/python3
 # from pprint import pprint
 import argparse
-
+import shutil
 from pyfiglet import Figlet
 from PyInquirer import prompt
 
-from flask_sketch.config import cli_style
+from flask_sketch.config import cli_style_2
 from flask_sketch.make import create_project
 from flask_sketch.questions import get_questions
 
@@ -31,13 +31,18 @@ f = Figlet(font="slant")
 def flask_sketch(args):
     print(f.renderText("Flask Sketch"))
 
-    answers = prompt(get_questions(), style=cli_style)
+    answers = prompt(get_questions(), style=cli_style_2)
     if answers:
-        # pprint(answers)
         create_project(args, answers)
 
 
 if __name__ == "__main__":
+
     args = parser.parse_args()
     args.project_name = args.project_name.lower()
-    flask_sketch(args)
+    try:
+        flask_sketch(args)
+    except Exception as e:
+        print("\n\nAn error occurred during generating files:")
+        print(e)
+        shutil.rmtree(args.project_name)
